"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, PathParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteServerRequestTypedDict(TypedDict):
    server_name: str


class DeleteServerRequest(BaseModel):
    server_name: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]


class DeleteServerResponseBodyTypedDict(TypedDict):
    r"""Delete Server"""

    message: NotRequired[str]
    status: NotRequired[str]


class DeleteServerResponseBody(BaseModel):
    r"""Delete Server"""

    message: Optional[str] = None

    status: Optional[str] = None


class DeleteServerResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DeleteServerResponseBodyTypedDict


class DeleteServerResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DeleteServerResponseBody
